@@ -2,13 +2,15 @@ from functools import wraps
 from typing import Union
 
 from localtileserver.client import TileClient
-from localtileserver.tileserver import (
+from localtileserver.helpers import parse_shapely
+from localtileserver.tiler import (
+    get_co_elevation_url,
     get_data_path,
     get_elevation_us_url,
     get_oam2_url,
-    get_pine_gulch_url,
     get_sf_bay_url,
 )
+from localtileserver.tiler.data import DIRECTORY
 
 
 def _get_example_client(
@@ -52,14 +54,14 @@ def get_bahamas(*args, **kwargs):
 
 
 @wraps(_get_example_client)
-def get_pine_gulch(*args, **kwargs):
-    path = get_pine_gulch_url()
+def get_landsat(*args, **kwargs):
+    path = get_data_path("landsat.tif")
     return TileClient(path, *args, **kwargs)
 
 
 @wraps(_get_example_client)
-def get_landsat(*args, **kwargs):
-    path = get_data_path("landsat.tif")
+def get_landsat7(*args, **kwargs):
+    path = get_data_path("landsat7.tif")
     return TileClient(path, *args, **kwargs)
 
 
@@ -79,3 +81,18 @@ def get_oam2(*args, **kwargs):
 def get_elevation_us(*args, **kwargs):
     path = get_elevation_us_url()
     return TileClient(path, *args, **kwargs)
+
+
+def load_presidio():
+    """Load Presidio of San Francisco boundary as Shapely Polygon."""
+    with open(DIRECTORY / "presidio.wkb", "rb") as f:
+        return parse_shapely(f.read())
+
+
+@wraps(_get_example_client)
+def get_co_elevation(*args, local_roi=False, **kwargs):
+    if local_roi:
+        path = get_data_path("co_elevation_roi.tif")
+    else:
+        path = get_co_elevation_url()
+    return TileClient(path, *args, **kwargs)
