@@ -4,13 +4,13 @@ from urllib.parse import urlencode
 
 import requests
 
-from localtileserver.tileserver import get_cache_dir
+from localtileserver.tiler import get_cache_dir
 
 
 def save_file_from_request(response: requests.Response, output_path: pathlib.Path):
     d = response.headers["content-disposition"]
     fname = re.findall("filename=(.+)", d)[0]
-    if not output_path:
+    if isinstance(output_path, bool) or not output_path:
         output_path = get_cache_dir() / fname
     with open(output_path, "wb") as f:
         f.write(response.content)
